@@ -11,7 +11,7 @@ Ami.more<-function()
      note_for_close_window()
      Amidpar<-data.frame(input=c("Css_trough (mg/L)","tau (hr)","tin (hr)"),value=c(0))
      Amidpar<-edit(Amidpar)
-     Amidpar<-check(Amidpar)
+##     Amidpar<-check(Amidpar)
      d<-Amidpar[1,2]/(((1-exp(-(samplesStats("cl"))/(samplesStats("v"))*Amidpar[3,2]))/(Amidpar[3,2]*(samplesStats("cl"))*(1-exp(-(samplesStats("cl"))/(samplesStats("v"))*Amidpar[2,2]))))*exp(-(samplesStats("cl"))/(samplesStats("v"))*(Amidpar[2,2]-Amidpar[3,2])))  
      sim<-matrix(d[1 ,1])
      doutput<-data.frame(sim)
@@ -29,7 +29,7 @@ Ami.more<-function()
           note_for_close_window()
           Amicpar<-data.frame(input=c("D (mg)","tau (hr)","tin (hr)"),value=c(0))                   
           Amicpar<-edit(Amicpar)                                                                     
-          Amicpar<-check(Amicpar)                                                                   
+##          Amicpar<-check(Amicpar)                                                                   
           C<-(Amicpar[1,2]*(1-exp(-(samplesStats("cl"))/(samplesStats("v"))*Amicpar[3,2]))/(Amicpar[3,2]*(samplesStats("cl"))*(1-exp(-(samplesStats("cl"))/(samplesStats("v"))*Amicpar[2,2]))))*exp(-(samplesStats("cl"))/(samplesStats("v"))*(Amicpar[2,2]-Amicpar[3,2]))   
           sim<-matrix(C[1 ,1])                                                                       
           coutput<-data.frame(sim)                                                                  
@@ -63,7 +63,7 @@ Van.more<-function()
      note_for_close_window()
      Vandpar<-data.frame(input=c("Css_trough (mg/L)","tau (hr)","tin (hr)"),value=c(0))
      Vandpar<-edit(Vandpar)
-     Vandpar<-check(Vandpar)
+##     Vandpar<-check(Vandpar)
      d<-Vandpar[1,2]/(((1-exp(-(samplesStats("cl"))/(samplesStats("v"))*Vandpar[3,2]))/(Vandpar[3,2]*(samplesStats("cl"))*(1-exp(-(samplesStats("cl"))/(samplesStats("v"))*Vandpar[2,2]))))*exp(-(samplesStats("cl"))/(samplesStats("v"))*(Vandpar[2,2]-Vandpar[2,2])))
      sim<-matrix(d[1 ,1])
      doutput<-data.frame(sim)
@@ -81,7 +81,7 @@ Van.more<-function()
      note_for_close_window()
      Vancpar<-data.frame(input=c("D (mg)","tau (hr)","tin (hr)"),value=c(0))
      Vancpar<-edit(Vancpar)
-     Vancpar<-check(Vancpar)
+##     Vancpar<-check(Vancpar)
      C<-(Vancpar[1,2]*(1-exp(-(samplesStats("cl"))/(samplesStats("v"))*Vancpar[3,2]))/(Vancpar[3,2]*(samplesStats("cl"))*(1-exp(-(samplesStats("cl"))/(samplesStats("v"))*Vancpar[2,2]))))*exp(-(samplesStats("cl"))/(samplesStats("v"))*(Vancpar[2,2]-Vancpar[3,2]))
      sim<-matrix(C[1 ,1])
      coutput<-data.frame(sim)
@@ -115,7 +115,7 @@ Car.more<-function()
      note_for_close_window()
      CBZdpar<-data.frame(input=c("Css_trough (mg/L)","tau (hr)"),value=c(0))
      CBZdpar<-edit(CBZdpar)
-     CBZdpar<-check(CBZdpar)
+##     CBZdpar<-check(CBZdpar)
      d<-CBZdpar[1,2]/(1.2/((samplesStats("v_F"))*(1.2-(samplesStats("cl_F"))/(samplesStats("v_F"))))*((1/(1-exp(-(samplesStats("cl_F"))/(samplesStats("v_F"))*CBZdpar[2,2])))*exp(-(samplesStats("cl_F"))/(samplesStats("v_F"))*CBZdpar[2,2])-(1/(1-exp(-1.2*CBZdpar[2,2])))*exp(-1.2*CBZdpar[2,2])))
      sim<-matrix(d[1 ,1])
      doutput<-data.frame(sim)
@@ -133,7 +133,7 @@ Car.more<-function()
      note_for_close_window()
      CBZcpar<-data.frame(input=c("D (mg)","tau (hr)"),value=c(0))
      CBZcpar<-edit(CBZcpar)
-     CBZcpar<-check(CBZcpar)
+##     CBZcpar<-check(CBZcpar)
      C<-1.2*CBZcpar[1,2]/((samplesStats("v_F"))*(1.2-(samplesStats("cl_F"))/(samplesStats("v_F"))))*((1/(1-exp(-(samplesStats("cl_F"))/(samplesStats("v_F"))*CBZcpar[2,2])))*exp(-(samplesStats("cl_F"))/(samplesStats("v_F"))*CBZcpar[2,2])-(1/(1-exp(-1.2*CBZcpar[2,2])))*exp(-1.2*CBZcpar[2,2]))
      sim<-matrix(C[1 ,1])
      coutput<-data.frame(sim)
@@ -167,7 +167,7 @@ Dig.more<-function()
      note_for_close_window()
      Digdpar<-data.frame(input=c("Css_trough (ng/mL)","tau (hr)"),value=c(0))
      Digdpar<-edit(Digdpar)
-     Digdpar<-check(Digdpar)
+##     Digdpar<-check(Digdpar)
      d<-Digdpar[1,2]*(samplesStats("cl_F"))*Digdpar[2,2]/1000
      sim<-matrix(d[1 ,1])
      doutput<-data.frame(sim)
@@ -185,7 +185,7 @@ Dig.more<-function()
       note_for_close_window()
       Digcpar<-data.frame(input=c("D (mg)","tau (hr)"),value=c(0))
       Digcpar<-edit(Digcpar)
-      Digcpar<-check(Digcpar)
+##      Digcpar<-check(Digcpar)
       C<-Digcpar[1,2]*1000/((samplesStats("cl_F"))*Digcpar[2,2])
       sim<-matrix(C[1 ,1])
       coutput<-data.frame(sim)
@@ -219,7 +219,7 @@ Lit.more<-function()
      note_for_close_window()
      Litdpar<-data.frame(input=c("Css (mEq/L)","tau (hr)"),value=c(0))
      Litdpar<-edit(Litdpar)
-     Litdpar<-check(Litdpar)
+##     Litdpar<-check(Litdpar)
      d<-Litdpar[1,2]*(samplesStats("cl_F"))*Litdpar[2,2]*36.9458
      sim<-matrix(d[1 ,1])
      doutput<-data.frame(sim)
@@ -237,7 +237,7 @@ Lit.more<-function()
      note_for_close_window()
      Litcpar<-data.frame(input=c("D (mg)","tau (hr)"),value=c(0))
      Litcpar<-edit(Litcpar)
-     Litcpar<-check(Litcpar)
+##     Litcpar<-check(Litcpar)
      C<-(Litcpar[1,2]/36.9458)/((samplesStats("cl_F"))*Litcpar[2,2])
      sim<-matrix(C[1 ,1])
      coutput<-data.frame(sim)
@@ -271,7 +271,7 @@ Litcit.more<-function()
      note_for_close_window()
      Litcitdpar<-data.frame(input=c("Css (mEq/L)","tau (hr)"),value=c(0))
      Litcitdpar<-edit(Litcitdpar)
-     Litcitdpar<-check(Litcitdpar)
+##     Litcitdpar<-check(Litcitdpar)
      d<-Litcitdpar[1,2]*(samplesStats("cl_F"))*Litcitdpar[2,2]*94
      sim<-matrix(d[1 ,1])
      doutput<-data.frame(sim)
@@ -289,7 +289,7 @@ Litcit.more<-function()
      note_for_close_window()
      Litcitcpar<-data.frame(input=c("D (mg)","tau (hr)"),value=c(0))
      Litcitcpar<-edit(Litcitcpar)
-     Litcitcpar<-check(Litcitcpar)
+##     Litcitcpar<-check(Litcitcpar)
      C<-(Litcitcpar[1,2]/94)/((samplesStats("cl_F"))*Litcitcpar[2,2])
      sim<-matrix(C[1 ,1])
      coutput<-data.frame(sim)
@@ -323,7 +323,7 @@ Enf.more<-function()
      note_for_close_window()
      Enfdpar<-data.frame(input=c("Css_trough (mg/L)","tau (hr)"),value=c(0))
      Enfdpar<-edit(Enfdpar)
-     Enfdpar<-check(Enfdpar)
+##     Enfdpar<-check(Enfdpar)
      d<-Enfdpar[1,2]/((samplesStats("ka"))/((samplesStats("v_F"))*((samplesStats("ka"))-(samplesStats("cl_F"))/(samplesStats("v_F"))))*((1/(1-exp(-(samplesStats("cl_F"))/(samplesStats("v_F"))*Enfdpar[2,2])))*exp(-(samplesStats("cl_F"))/(samplesStats("v_F"))*Enfdpar[2,2])-(1/(1-exp(-(samplesStats("ka"))*Enfdpar[2,2])))*exp(-(samplesStats("ka"))*Enfdpar[2,2])))
      sim<-matrix(d[1 ,1])
      doutput<-data.frame(sim)
@@ -341,7 +341,7 @@ Enf.more<-function()
      note_for_close_window()
      Enfcpar<-data.frame(input=c("D (mg)","tau (hr)"),value=c(0))
      Enfcpar<-edit(Enfcpar)
-     Enfcpar<-check(Enfcpar)
+##     Enfcpar<-check(Enfcpar)
      C<-(samplesStats("ka"))*Enfcpar[1,2]/((samplesStats("v_F"))*((samplesStats("ka"))-(samplesStats("cl_F"))/(samplesStats("v_F"))))*((1/(1-exp(-(samplesStats("cl_F"))/(samplesStats("v_F"))*Enfcpar[2,2])))*exp(-(samplesStats("cl_F"))/(samplesStats("v_F"))*Enfcpar[2,2])-(1/(1-exp(-(samplesStats("ka"))*Enfcpar[2,2])))*exp(-(samplesStats("ka"))*Enfcpar[2,2]))
      sim<-matrix(C[1 ,1])
      coutput<-data.frame(sim)
@@ -375,7 +375,7 @@ Ind.more<-function()
      note_for_close_window()
      Inddpar<-data.frame(input=c("Css_trough (mg/L)","tau (hr)"),value=c(0))
      Inddpar<-edit(Inddpar)
-     Inddpar<-check(Inddpar)
+##     Inddpar<-check(Inddpar)
      d<-Inddpar[1,2]/((samplesStats("ka"))/(65.7*((samplesStats("ka"))-(samplesStats("cl_F"))/65.7))*((1/(1-exp(-(samplesStats("cl_F"))/65.7*Inddpar[2,2])))*exp(-(samplesStats("cl_F"))/65.7*Inddpar[2,2])-(1/(1-exp(-(samplesStats("ka"))*Inddpar[2,2])))*exp(-(samplesStats("ka"))*Inddpar[2,2])))
      sim<-matrix(d[1 ,1])
      doutput<-data.frame(sim)
@@ -393,7 +393,7 @@ Ind.more<-function()
      note_for_close_window()
      Indcpar<-data.frame(input=c("D (mg)","tau (hr)"),value=c(0))
      Indcpar<-edit(Indcpar)
-     Indcpar<-check(Indcpar)
+##     Indcpar<-check(Indcpar)
      C<-(samplesStats("ka"))*Indcpar[1,2]/(65.7*((samplesStats("ka"))-(samplesStats("cl_F"))/65.7))*((1/(1-exp(-(samplesStats("cl_F"))/65.7*Indcpar[2,2])))*exp(-(samplesStats("cl_F"))/65.7*Indcpar[2,2])-(1/(1-exp(-(samplesStats("ka"))*Indcpar[2,2])))*exp(-(samplesStats("ka"))*Indcpar[2,2]))
      sim<-matrix(C[1 ,1])
      coutput<-data.frame(sim)
@@ -427,7 +427,7 @@ Rit.more<-function()
      note_for_close_window()
      Ritdpar<-data.frame(input=c("Css_trough (mg/L)","tau (hr)"),value=c(0))
      Ritdpar<-edit(Ritdpar)
-     Ritdpar<-check(Ritdpar)
+##     Ritdpar<-check(Ritdpar)
      d<-Ritdpar[1,2]/((samplesStats("ka"))/((samplesStats("v_F"))*((samplesStats("ka"))-(samplesStats("cl_F"))/(samplesStats("v_F"))))*((1/(1-exp(-(samplesStats("cl_F"))/(samplesStats("v_F"))*Ritdpar[2,2])))*exp(-(samplesStats("cl_F"))/(samplesStats("v_F"))*(Ritdpar[2,2]-0.778))-(1/(1-exp(-(samplesStats("ka"))*Ritdpar[2,2])))*exp(-(samplesStats("ka"))*(Ritdpar[2,2]-0.778))))
      sim<-matrix(d[1 ,1])
      doutput<-data.frame(sim)
@@ -445,7 +445,7 @@ Rit.more<-function()
      note_for_close_window()
      Ritcpar<-data.frame(input=c("D (mg)","tau (hr)"),value=c(0))
      Ritcpar<-edit(Ritcpar)
-     Ritcpar<-check(Ritcpar)
+##     Ritcpar<-check(Ritcpar)
      C<-(samplesStats("ka"))*Ritcpar[1,2]/((samplesStats("v_F"))*((samplesStats("ka"))-(samplesStats("cl_F"))/(samplesStats("v_F"))))*((1/(1-exp(-(samplesStats("cl_F"))/(samplesStats("v_F"))*Ritcpar[2,2])))*exp(-(samplesStats("cl_F"))/(samplesStats("v_F"))*(Ritcpar[2,2]-0.778))-(1/(1-exp(-(samplesStats("ka"))*Ritcpar[2,2])))*exp(-(samplesStats("ka"))*(Ritcpar[2,2]-0.778)))
      sim<-matrix(C[1 ,1])
      coutput<-data.frame(sim)
@@ -479,7 +479,7 @@ Eve.more<-function()
      note_for_close_window()
      Evedpar<-data.frame(input=c("Css_trough (mcg/L)","tau (hr)"),value=c(0))
      Evedpar<-edit(Evedpar)
-     Evedpar<-check(Evedpar)
+##     Evedpar<-check(Evedpar)
      d<-Evedpar[1,2]/(6.07/((samplesStats("v_F"))*(6.07-(samplesStats("cl_F"))/(samplesStats("v_F"))))*((1/(1-exp(-(samplesStats("cl_F"))/(samplesStats("v_F"))*Evedpar[2,2])))*exp(-(samplesStats("cl_F"))/(samplesStats("v_F"))*Evedpar[2,2])-(1/(1-exp(-6.07*Evedpar[2,2])))*exp(-6.07*Evedpar[2,2]))*1000)
      sim<-matrix(d[1 ,1])
      doutput<-data.frame(sim)
@@ -497,7 +497,7 @@ Eve.more<-function()
      note_for_close_window()
      Evecpar<-data.frame(input=c("D (mg)","tau (hr)"),value=c(0))
      Evecpar<-edit(Evecpar)
-     Evecpar<-check(Evecpar)
+##     Evecpar<-check(Evecpar)
      C<-6.07*Evecpar[1,2]/((samplesStats("v_F"))*(6.07-(samplesStats("cl_F"))/(samplesStats("v_F"))))*((1/(1-exp(-(samplesStats("cl_F"))/(samplesStats("v_F"))*Evecpar[2,2])))*exp(-(samplesStats("cl_F"))/(samplesStats("v_F"))*Evecpar[2,2])-(1/(1-exp(-6.07*Evecpar[2,2])))*exp(-6.07*Evecpar[2,2]))*1000
      sim<-matrix(C[1 ,1])
      coutput<-data.frame(sim)
@@ -531,7 +531,7 @@ Tac.more<-function()
      note_for_close_window()
      Tacdpar<-data.frame(input=c("Css_trough (mcg/mL)","tau (hr)"),value=c(0))
      Tacdpar<-edit(Tacdpar)
-     Tacdpar<-check(Tacdpar)
+##     Tacdpar<-check(Tacdpar)
      d<-Tacdpar[1,2]/(4.5/(314*(4.5-(samplesStats("cl_F"))/314))*((1/(1-exp(-(samplesStats("cl_F"))/314*Tacdpar[2,2])))*exp(-(samplesStats("cl_F"))/314*Tacdpar[2,2])-(1/(1-exp(-4.5*Tacdpar[2,2])))*exp(-4.5*Tacdpar[2,2]))*1000)
      sim<-matrix(d[1 ,1])
      doutput<-data.frame(sim)
@@ -549,7 +549,7 @@ Tac.more<-function()
      note_for_close_window()
      Taccpar<-data.frame(input=c("D (mg)","tau (hr)"),value=c(0))
      Taccpar<-edit(Taccpar)
-     Taccpar<-check(Taccpar)
+##     Taccpar<-check(Taccpar)
      C<-4.5*Taccpar[1,2]/(314*(4.5-(samplesStats("cl_F"))/314))*((1/(1-exp(-(samplesStats("cl_F"))/314*Taccpar[2,2])))*exp(-(samplesStats("cl_F"))/314*Taccpar[2,2])-(1/(1-exp(-4.5*Taccpar[2,2])))*exp(-4.5*Taccpar[2,2]))*1000
      sim<-matrix(C[1 ,1])
      coutput<-data.frame(sim)
@@ -583,7 +583,7 @@ Eno.more<-function()
      note_for_close_window()
      Enodpar<-data.frame(input=c("Amax (IU/mL)","tau (hr)"),value=c(0))
      Enodpar<-edit(Enodpar)
-     Enodpar<-check(Enodpar)
+##     Enodpar<-check(Enodpar)
      d<-Enodpar[1,2]/(exp(-(samplesStats("cl_F"))/(samplesStats("v_F"))*(log(0.34*(1-exp(-(samplesStats("cl_F"))/(samplesStats("v_F"))*Enodpar[2,2]))/((samplesStats("cl_F"))/(samplesStats("v_F"))*(1-exp(-0.34*Enodpar[2,2])))))/(0.34-(samplesStats("cl_F"))/(samplesStats("v_F"))))/(samplesStats("v_F"))*(1-exp(-(samplesStats("cl_F"))/(samplesStats("v_F"))*Enodpar[2,2]))/1000)
      sim<-matrix(d[1 ,1])
      doutput<-data.frame(sim)
@@ -601,7 +601,7 @@ Eno.more<-function()
      note_for_close_window()
      Enocpar<-data.frame(input=c("D (IU)","tau (hr)"),value=c(0))
      Enocpar<-edit(Enocpar)
-     Enocpar<-check(Enocpar)
+##     Enocpar<-check(Enocpar)
      C<-Enocpar[1,2]*exp(-(samplesStats("cl_F"))/(samplesStats("v_F"))*(log(0.34*(1-exp(-(samplesStats("cl_F"))/(samplesStats("v_F"))*Enocpar[2,2]))/((samplesStats("cl_F"))/(samplesStats("v_F"))*(1-exp(-0.34*Enocpar[2,2])))))/(0.34-(samplesStats("cl_F"))/(samplesStats("v_F"))))/(samplesStats("v_F"))*(1-exp(-(samplesStats("cl_F"))/(samplesStats("v_F"))*Enocpar[2,2]))/1000
      sim<-matrix(C[1 ,1])
      coutput<-data.frame(sim)
@@ -635,7 +635,7 @@ Amianhir.more<-function()
      note_for_close_window()
      Amianhirdpar<-data.frame(input=c("Css_trough (mg/L)","tau (hr)"),value=c(0))
      Amianhirdpar<-edit(Amianhirdpar)
-     Amianhirdpar<-check(Amianhirdpar)
+##     Amianhirdpar<-check(Amianhirdpar)
      d<-Amianhirdpar[1,2]/(0.85*1.85/((samplesStats("v_F"))*(1.85-(samplesStats("cl_F"))/(samplesStats("v_F"))))*((1/(1-exp(-(samplesStats("cl_F"))/(samplesStats("v_F"))*Amianhirdpar[2,2])))*exp(-(samplesStats("cl_F"))/(samplesStats("v_F"))*Amianhirdpar[2,2])-(1/(1-exp(-1.85*Amianhirdpar[2,2])))*exp(-1.85*Amianhirdpar[2,2])))
      sim<-matrix(d[1 ,1])
      doutput<-data.frame(sim)
@@ -653,7 +653,7 @@ Amianhir.more<-function()
      note_for_close_window()
      Amianhircpar<-data.frame(input=c("D (mg)","tau (hr)"),value=c(0))
      Amianhircpar<-edit(Amianhircpar)
-     Amianhircpar<-check(Amianhircpar)
+##     Amianhircpar<-check(Amianhircpar)
      C<-0.85*1.85*Amianhircpar[1,2]/((samplesStats("v_F"))*(1.85-(samplesStats("cl_F"))/(samplesStats("v_F"))))*((1/(1-exp(-(samplesStats("cl_F"))/(samplesStats("v_F"))*Amianhircpar[2,2])))*exp(-(samplesStats("cl_F"))/(samplesStats("v_F"))*Amianhircpar[2,2])-(1/(1-exp(-1.85*Amianhircpar[2,2])))*exp(-1.85*Amianhircpar[2,2]))
      sim<-matrix(C[1 ,1])
      coutput<-data.frame(sim)
@@ -687,7 +687,7 @@ Amianhcr.more<-function()
      note_for_close_window()
      Amianhcrdpar<-data.frame(input=c("Css_trough (mg/L)","tau (hr)"),value=c(0))
      Amianhcrdpar<-edit(Amianhcrdpar)
-     Amianhcrdpar<-check(Amianhcrdpar)
+##     Amianhcrdpar<-check(Amianhcrdpar)
      d<-Amianhcrdpar[1,2]*samplesStats("cl_F")*Amianhcrdpar[2,2]/0.85
      sim<-matrix(d[1 ,1])
      doutput<-data.frame(sim)
@@ -705,7 +705,7 @@ Amianhcr.more<-function()
      note_for_close_window()
      Amianhcrcpar<-data.frame(input=c("D (mg)","tau (hr)"),value=c(0))
      Amianhcrcpar<-edit(Amianhcrcpar)
-     Amianhcrcpar<-check(Amianhcrcpar)
+##     Amianhcrcpar<-check(Amianhcrcpar)
      C<-0.85*Amianhcrcpar[1,2]/(samplesStats("cl_F")*Amianhcrcpar[2,2])
      sim<-matrix(C[1 ,1])
      coutput<-data.frame(sim)
@@ -739,7 +739,7 @@ Amianhinfusion.more<-function()
      note_for_close_window()
      Amianhinfusiondpar<-data.frame(input=c("Css_trough (mg/L)"),value=c(0))
      Amianhinfusiondpar<-edit(Amianhinfusiondpar)
-     Amianhinfusiondpar<-check(Amianhinfusiondpar)
+##     Amianhinfusiondpar<-check(Amianhinfusiondpar)
      d<-Amianhinfusiondpar[1,2]*samplesStats("cl")/0.85
      sim<-matrix(d[1 ,1])
      doutput<-data.frame(sim)
@@ -757,7 +757,7 @@ Amianhinfusion.more<-function()
      note_for_close_window()
      Amianhinfusioncpar<-data.frame(input=c("R (mg/hr)"),value=c(0))
      Amianhinfusioncpar<-edit(Amianhinfusioncpar)
-     Amianhinfusioncpar<-check(Amianhinfusioncpar)
+##     Amianhinfusioncpar<-check(Amianhinfusioncpar)
      C<-0.85*Amianhinfusioncpar[1,2]/(samplesStats("cl"))
      sim<-matrix(C[1 ,1])
      coutput<-data.frame(sim)
@@ -792,7 +792,7 @@ Amidihir.more<-function()
      note_for_close_window()
      Amidihirdpar<-data.frame(input=c("Css_trough (mg/L)","tau (hr)"),value=c(0))
      Amidihirdpar<-edit(Amidihirdpar)
-     Amidihirdpar<-check(Amidihirdpar)
+##     Amidihirdpar<-check(Amidihirdpar)
      d<-Amidihirdpar[1,2]/(0.8*1.85/((samplesStats("v_F"))*(1.85-(samplesStats("cl_F"))/(samplesStats("v_F"))))*((1/(1-exp(-(samplesStats("cl_F"))/(samplesStats("v_F"))*Amidihirdpar[2,2])))*exp(-(samplesStats("cl_F"))/(samplesStats("v_F"))*Amidihirdpar[2,2])-(1/(1-exp(-1.85*Amidihirdpar[2,2])))*exp(-1.85*Amidihirdpar[2,2])))
      sim<-matrix(d[1 ,1])
      doutput<-data.frame(sim)
@@ -810,7 +810,7 @@ Amidihir.more<-function()
      note_for_close_window()
      Amidihircpar<-data.frame(input=c("D (mg)","tau (hr)"),value=c(0))
      Amidihircpar<-edit(Amidihircpar)
-     Amidihircpar<-check(Amidihircpar)
+##     Amidihircpar<-check(Amidihircpar)
      C<-1.85*0.8*Amidihircpar[1,2]/((samplesStats("v_F"))*(1.85-(samplesStats("cl_F"))/(samplesStats("v_F"))))*((1/(1-exp(-(samplesStats("cl_F"))/(samplesStats("v_F"))*Amidihircpar[2,2])))*exp(-(samplesStats("cl_F"))/(samplesStats("v_F"))*Amidihircpar[2,2])-(1/(1-exp(-1.85*Amidihircpar[2,2])))*exp(-1.85*Amidihircpar[2,2]))
      sim<-matrix(C[1 ,1])
      coutput<-data.frame(sim)
@@ -844,7 +844,7 @@ Amidihcr.more<-function()
      note_for_close_window()
      Amidihcrdpar<-data.frame(input=c("Css_trough (mg/L)","tau (hr)"),value=c(0))
      Amidihcrdpar<-edit(Amidihcrdpar)
-     Amidihcrdpar<-check(Amidihcrdpar)
+##     Amidihcrdpar<-check(Amidihcrdpar)
      d<-Amidihcrdpar[1,2]*samplesStats("cl_F")*Amidihcrdpar[2,2]/0.8
      sim<-matrix(d[1 ,1])
      doutput<-data.frame(sim)
@@ -862,7 +862,7 @@ Amidihcr.more<-function()
      note_for_close_window()
      Amidihcrcpar<-data.frame(input=c("D (mg)","tau (hr)"),value=c(0))
      Amidihcrcpar<-edit(Amidihcrcpar)
-     Amidihcrcpar<-check(Amidihcrcpar)
+##     Amidihcrcpar<-check(Amidihcrcpar)
      C<-0.8*Amidihcrcpar[1,2]/(samplesStats("cl_F")*Amidihcrcpar[2,2])
      sim<-matrix(C[1 ,1])
      coutput<-data.frame(sim)
@@ -896,7 +896,7 @@ Amidihinfusion.more<-function()
      note_for_close_window()
      Amidihinfusiondpar<-data.frame(input=c("Css_trough (mg/L)"),value=c(0))
      Amidihinfusiondpar<-edit(Amidihinfusiondpar)
-     Amidihinfusiondpar<-check(Amidihinfusiondpar)
+##     Amidihinfusiondpar<-check(Amidihinfusiondpar)
      d<-Amidihinfusiondpar[1,2]*samplesStats("cl")/0.8
      sim<-matrix(d[1 ,1])
      doutput<-data.frame(sim)
@@ -914,7 +914,7 @@ Amidihinfusion.more<-function()
      note_for_close_window()
      Amidihinfusioncpar<-data.frame(input=c("R (mg/hr)"),value=c(0))
      Amidihinfusioncpar<-edit(Amidihinfusioncpar)
-     Amidihinfusioncpar<-check(Amidihinfusioncpar)
+##     Amidihinfusioncpar<-check(Amidihinfusioncpar)
      C<-0.8*Amidihinfusioncpar[1,2]/(samplesStats("cl"))
      sim<-matrix(C[1 ,1])
      coutput<-data.frame(sim)
@@ -948,7 +948,7 @@ Oxtir.more<-function()
      note_for_close_window()
      Oxtirdpar<-data.frame(input=c("Css_trough (mg/L)","tau (hr)"),value=c(0))
      Oxtirdpar<-edit(Oxtirdpar)
-     Oxtirdpar<-check(Oxtirdpar)
+##     Oxtirdpar<-check(Oxtirdpar)
      d<-Oxtirdpar[1,2]/(0.65*1.85/((samplesStats("v_F"))*(1.85-(samplesStats("cl_F"))/(samplesStats("v_F"))))*((1/(1-exp(-(samplesStats("cl_F"))/(samplesStats("v_F"))*Oxtirdpar[2,2])))*exp(-(samplesStats("cl_F"))/(samplesStats("v_F"))*Oxtirdpar[2,2])-(1/(1-exp(-1.85*Oxtirdpar[2,2])))*exp(-1.85*Oxtirdpar[2,2])))
      sim<-matrix(d[1 ,1])
      doutput<-data.frame(sim)
@@ -966,7 +966,7 @@ Oxtir.more<-function()
      note_for_close_window()
      Oxtircpar<-data.frame(input=c("D (mg)","tau (hr)"),value=c(0))
      Oxtircpar<-edit(Oxtircpar)
-     Oxtircpar<-check(Oxtircpar)
+##     Oxtircpar<-check(Oxtircpar)
      C<-1.85*0.65*Oxtircpar[1,2]/((samplesStats("v_F"))*(1.85-(samplesStats("cl_F"))/(samplesStats("v_F"))))*((1/(1-exp(-(samplesStats("cl_F"))/(samplesStats("v_F"))*Oxtircpar[2,2])))*exp(-(samplesStats("cl_F"))/(samplesStats("v_F"))*Oxtircpar[2,2])-(1/(1-exp(-1.85*Oxtircpar[2,2])))*exp(-1.85*Oxtircpar[2,2]))
      sim<-matrix(C[1 ,1])
      coutput<-data.frame(sim)
@@ -1001,7 +1001,7 @@ Oxtcr.more<-function()
      note_for_close_window()
      Oxtcrdpar<-data.frame(input=c("Css_trough (mg/L)","tau (hr)"),value=c(0))
      Oxtcrdpar<-edit(Oxtcrdpar)
-     Oxtcrdpar<-check(Oxtcrdpar)
+##     Oxtcrdpar<-check(Oxtcrdpar)
      d<-Oxtcrdpar[1,2]*samplesStats("cl_F")*Oxtcrdpar[2,2]/0.65
      sim<-matrix(d[1 ,1])
      doutput<-data.frame(sim)
@@ -1019,7 +1019,7 @@ Oxtcr.more<-function()
      note_for_close_window()
      Oxtcrcpar<-data.frame(input=c("D (mg)","tau (hr)"),value=c(0))
      Oxtcrcpar<-edit(Oxtcrcpar)
-     Oxtcrcpar<-check(Oxtcrcpar)
+##     Oxtcrcpar<-check(Oxtcrcpar)
      C<-0.65*Oxtcrcpar[1,2]/(samplesStats("cl_F")*Oxtcrcpar[2,2])
      sim<-matrix(C[1 ,1])
      coutput<-data.frame(sim)
@@ -1054,7 +1054,7 @@ Their.more<-function()
      note_for_close_window()
      Theirdpar<-data.frame(input=c("Css_trough (mg/L)","tau (hr)"),value=c(0))
      Theirdpar<-edit(Theirdpar)
-     Theirdpar<-check(Theirdpar)
+##     Theirdpar<-check(Theirdpar)
      d<-Theirdpar[1,2]/(1.85/((samplesStats("v_F"))*(1.85-(samplesStats("cl_F"))/(samplesStats("v_F"))))*((1/(1-exp(-(samplesStats("cl_F"))/(samplesStats("v_F"))*Theirdpar[2,2])))*exp(-(samplesStats("cl_F"))/(samplesStats("v_F"))*Theirdpar[2,2])-(1/(1-exp(-1.85*Theirdpar[2,2])))*exp(-1.85*Theirdpar[2,2])))
      sim<-matrix(d[1 ,1])
      doutput<-data.frame(sim)
@@ -1072,7 +1072,7 @@ Their.more<-function()
      note_for_close_window()
      Theircpar<-data.frame(input=c("D (mg)","tau (hr)"),value=c(0))
      Theircpar<-edit(Theircpar)
-     Theircpar<-check(Theircpar)
+##     Theircpar<-check(Theircpar)
      C<-1.85*Theircpar[1,2]/((samplesStats("v_F"))*(1.85-(samplesStats("cl_F"))/(samplesStats("v_F"))))*((1/(1-exp(-(samplesStats("cl_F"))/(samplesStats("v_F"))*Theircpar[2,2])))*exp(-(samplesStats("cl_F"))/(samplesStats("v_F"))*Theircpar[2,2])-(1/(1-exp(-1.85*Theircpar[2,2])))*exp(-1.85*Theircpar[2,2]))
      sim<-matrix(C[1 ,1])
      coutput<-data.frame(sim)
@@ -1106,7 +1106,7 @@ Thecr.more<-function()
      note_for_close_window()
      Thecrdpar<-data.frame(input=c("Css_trough (mg/L)","tau (hr)"),value=c(0))
      Thecrdpar<-edit(Thecrdpar)
-     Thecrdpar<-check(Thecrdpar)
+##     Thecrdpar<-check(Thecrdpar)
      d<-Thecrdpar[1,2]*samplesStats("cl_F")*Thecrdpar[2,2]
      sim<-matrix(d[1 ,1])
      doutput<-data.frame(sim)
@@ -1124,7 +1124,7 @@ Thecr.more<-function()
      note_for_close_window()
      Thecrcpar<-data.frame(input=c("D (mg)","tau (hr)"),value=c(0))
      Thecrcpar<-edit(Thecrcpar)
-     Thecrcpar<-check(Thecrcpar)
+##     Thecrcpar<-check(Thecrcpar)
      C<-Thecrcpar[1,2]/(samplesStats("cl_F")*Thecrcpar[2,2])
      sim<-matrix(C[1 ,1])
      coutput<-data.frame(sim)
@@ -1157,7 +1157,7 @@ Val.more<-function(A)
      note_for_close_window()
      Valdpar<-data.frame(input=c("Css_trough (mg/L)","tau (hr)"),value=c(0))
      Valdpar<-edit(Valdpar)
-     Valdpar<-check(Valdpar)
+##     Valdpar<-check(Valdpar)
      d<-Valdpar[1,2]/(A/(11.5*(A-(samplesStats("cl"))/11.5))*((1/(1-exp(-(samplesStats("cl"))/11.5*Valdpar[2,2])))*exp(-(samplesStats("cl"))/11.5*Valdpar[2,2])-(1/(1-exp(-A*Valdpar[2,2])))*exp(-A*Valdpar[2,2])))
      sim<-matrix(d[1 ,1])
      doutput<-data.frame(sim)
@@ -1175,7 +1175,7 @@ Val.more<-function(A)
      note_for_close_window()
      Valcpar<-data.frame(input=c("D (mg)","tau (hr)"),value=c(0))
      Valcpar<-edit(Valcpar)
-     Valcpar<-check(Valcpar)
+##     Valcpar<-check(Valcpar)
      C<-A*Valcpar[1,2]/(11.5*(A-(samplesStats("cl"))/11.5))*((1/(1-exp(-(samplesStats("cl"))/11.5*Valcpar[2,2])))*exp(-(samplesStats("cl"))/11.5*Valcpar[2,2])-(1/(1-exp(-A*Valcpar[2,2])))*exp(-A*Valcpar[2,2]))
      sim<-matrix(C[1 ,1])
      coutput<-data.frame(sim)
@@ -1210,7 +1210,7 @@ Cyc.more<-function(A,B)
      note_for_close_window()
      Cycdpar<-data.frame(input=c("Css_trough (mcg/L)","tau (hr)"),value=c(0))
      Cycdpar<-edit(Cycdpar)
-     Cycdpar<-check(Cycdpar)
+##     Cycdpar<-check(Cycdpar)
      d<-Cycdpar[1,2]/((0.2+10*abs(A-7)/((A+10)*60))*1000*0.3/((4*B)*(0.3-(samplesStats("cl")/(4*B))))*((1/(1-exp(-(samplesStats("cl")/(4*B))*Cycdpar[2,2])))*exp(-(samplesStats("cl"))/(4*B)*Cycdpar[2,2])-(1/(1-exp(-0.3*Cycdpar[2,2])))*exp(-0.3*Cycdpar[2,2])))
      sim<-matrix(d[1 ,1])
      doutput<-data.frame(sim)
@@ -1228,7 +1228,7 @@ Cyc.more<-function(A,B)
      note_for_close_window()
      Cyccpar<-data.frame(input=c("D (mg)","tau (hr)"),value=c(0))
      Cyccpar<-edit(Cyccpar)
-     Cyccpar<-check(Cyccpar)
+##     Cyccpar<-check(Cyccpar)
      C<-(0.2+10*abs(A-7)/((A+10)*60))*Cyccpar[1,2]*1000*0.3/((4*B)*(0.3-(samplesStats("cl")/(4*B))))*((1/(1-exp(-(samplesStats("cl")/(4*B))*Cyccpar[2,2])))*exp(-(samplesStats("cl"))/(4*B)*Cyccpar[2,2])-(1/(1-exp(-0.3*Cyccpar[2,2])))*exp(-0.3*Cyccpar[2,2]))
      sim<-matrix(C[1 ,1])
      coutput<-data.frame(sim)
@@ -1262,7 +1262,7 @@ Ima.more<-function()
      note_for_close_window()
      Imadpar<-data.frame(input=c("Css_trough (mg/L)","tau (hr)"),value=c(0))
      Imadpar<-edit(Imadpar)
-     Imadpar<-check(Imadpar)
+##     Imadpar<-check(Imadpar)
      d<-Imadpar[1,2]/(((1/(1.5*(samplesStats("cl_F"))))*(1-exp(-(samplesStats("cl_F"))/(samplesStats("v_F"))*1.5))*(exp(-(samplesStats("cl_F"))/(samplesStats("v_F"))*(Imadpar[2,2]-1.5))))/(1-(exp(-(samplesStats("cl_F"))/(samplesStats("v_F"))*Imadpar[2,2]))))
      sim<-matrix(d[1 ,1])
      doutput<-data.frame(sim)
@@ -1280,7 +1280,7 @@ Ima.more<-function()
      note_for_close_window()
      Imacpar<-data.frame(input=c("D (mg)","tau (hr)"),value=c(0))
      Imacpar<-edit(Imacpar)
-     Imacpar<-check(Imacpar)
+##     Imacpar<-check(Imacpar)
      C<-((Imacpar[1,2]/(1.5*(samplesStats("cl_F"))))*(1-exp(-(samplesStats("cl_F"))/(samplesStats("v_F"))*1.5))*(exp(-(samplesStats("cl_F"))/(samplesStats("v_F"))*(Imacpar[2,2]-1.5))))/(1-(exp(-(samplesStats("cl_F"))/(samplesStats("v_F"))*Imacpar[2,2])))
      sim<-matrix(C[1 ,1])
      coutput<-data.frame(sim)
@@ -1315,7 +1315,7 @@ ChiVal.more<-function(A)
      note_for_close_window()
      ChiValdpar<-data.frame(input=c("Css_trough (mg/L)","tau (hr)"),value=c(0))
      ChiValdpar<-edit(ChiValdpar)
-     ChiValdpar<-check(ChiValdpar)
+##     ChiValdpar<-check(ChiValdpar)
      d<-ChiValdpar[1,2]/(1.9/((0.24*A)*(1.9-(samplesStats("cl"))/(0.24*A)))*((1/(1-exp(-(samplesStats("cl"))/(0.24*A)*ChiValdpar[2,2])))*exp(-(samplesStats("cl"))/(0.24*A)*ChiValdpar[2,2])-(1/(1-exp(-1.9*ChiValdpar[2,2])))*exp(-1.9*ChiValdpar[2,2])))
      sim<-matrix(d[1 ,1])
      doutput<-data.frame(sim)
@@ -1333,7 +1333,7 @@ ChiVal.more<-function(A)
      note_for_close_window()
      ChiValcpar<-data.frame(input=c("D (mg)","tau (hr)"),Value=c(0))
      ChiValcpar<-edit(ChiValcpar)
-     ChiValcpar<-check(ChiValcpar)
+##     ChiValcpar<-check(ChiValcpar)
      C<-1.9*ChiValcpar[1,2]/((0.24*A)*(1.9-(samplesStats("cl"))/(0.24*A)))*((1/(1-exp(-(samplesStats("cl"))/(0.24*A)*ChiValcpar[2,2])))*exp(-(samplesStats("cl"))/(0.24*A)*ChiValcpar[2,2])-(1/(1-exp(-1.9*ChiValcpar[2,2])))*exp(-1.9*ChiValcpar[2,2]))
      sim<-matrix(C[1 ,1])
      coutput<-data.frame(sim)
@@ -1369,7 +1369,7 @@ Phe.more<-function()
      note_for_close_window()
      Phedpar<-data.frame(input=c("Css (mg/L)","tau (hr)"),value=c(0))
      Phedpar<-edit(Phedpar)
-     Phedpar<-check(Phedpar)
+##     Phedpar<-check(Phedpar)
      d<-((samplesStats("Vmax"))*Phedpar[1,2])/((samplesStats("Km"))+Phedpar[1,2])/(24/Phedpar[2,2])
      sim<-matrix(d[1 ,1])
      doutput<-data.frame(sim)
@@ -1387,7 +1387,7 @@ Phe.more<-function()
      note_for_close_window()
      Phecpar<-data.frame(input=c("D (mg)","tau (hr)"),value=c(0))
      Phecpar<-edit(Phecpar)
-     Phecpar<-check(Phecpar)
+##     Phecpar<-check(Phecpar)
      Phelimit(Phecpar[1,2],Phecpar[2,2])    
          } else {
              if (pick == 2){
@@ -1414,7 +1414,7 @@ War.more<-function()
      note_for_close_window()
      Wardpar<-data.frame(input=c("INR","tau (day)"),value=c(0))
      Wardpar<-edit(Wardpar)
-     Wardpar<-check(Wardpar)
+##     Wardpar<-check(Wardpar)
      d<-Wardpr(Wardpar[1,2],Wardpar[2,2])
      sim<-matrix(d[1 ,1])
      doutput<-data.frame(sim)
@@ -1432,7 +1432,7 @@ War.more<-function()
      note_for_close_window()
      Warcpar<-data.frame(input=c("D (mg)","tau (day)"),value=c(0))
      Warcpar<-edit(Warcpar)
-     Warcpar<-check(Warcpar)
+##     Warcpar<-check(Warcpar)
      C<-Warcpr(Warcpar[1,2],Warcpar[2,2])
      sim<-matrix(C[1 ,1])
      coutput<-data.frame(sim)
